@@ -2,7 +2,7 @@ use std::env;
 
 const IGNORED_LINTS: &[&str] = &["dead_code"];
 
-pub(crate) fn toml() -> toml::Value {
+pub(crate) fn toml(extra_rustflags: &[&'static str]) -> toml::Value {
     let mut rustflags = vec!["--cfg", "trybuild", "--verbose"];
 
     for &lint in IGNORED_LINTS {
@@ -18,5 +18,7 @@ pub(crate) fn toml() -> toml::Value {
         }
     }
 
+    rustflags.extend(extra_rustflags);
+
     toml::Value::try_from(rustflags).unwrap()
 }
